import { html } from 'lit-html';
const meta = {
    title: 'Anchor',
    component: 'rapid-anchor',
};
export default meta;
const wrapperStyle = 'display: flex; flex-direction: column;';
const textStyle = 'font-size:13px;font-weight:600;color:white; padding: 8px 0px;';
const StylesMapperTemplate = {
    render: ({ appearances, anchorText }) => html `
    <div style="${wrapperStyle}">
      ${appearances.map((appearanceName) => html `
          <h3 style="${textStyle}">${appearanceName}</div>
          <div style="display: flex; flex-direction: row; gap:16px;margin: 8px 0;">
            <rapid-anchor appearance="${appearanceName}">
              ${anchorText}
            </rapid-anchor>
          </div>
        `)}
    </div>
  `,
};
const FastAppearanceValues = [
    'accent',
    'neutral',
    'outline',
    'stealth',
    'lightweight',
    'hypertext',
];
const RapidAppearanceValues = ['primary', 'primary-outline', 'neutral', 'neutral-outline', 'link'];
export const Default = {
    args: {
        appearance: 'primary',
        target: '_blank',
        href: 'https://www.microsoft.com',
    },
    argTypes: {
        appearance: {
            control: 'select',
            options: [...RapidAppearanceValues, ...FastAppearanceValues],
        },
    },
    render: ({ appearance, target, href }) => html `
    <div style="${wrapperStyle}">
      <h3 style="${textStyle}">${appearance}</div>
      <div style="display: flex; flex-direction: row; gap:16px;margin: 8px 0;">
        <rapid-anchor appearance="${appearance}" target="${target}" href="${href}" >Anchor</rapid-anchor>
        <rapid-anchor appearance="${appearance}">
          Anchor
          <rapid-icon name="check" size="md" slot="end"></rapid-icon>
        </rapid-anchor>
      </div>
    </div>`,
};
export const RapidAnchorAppearances = Object.assign({ args: {
        appearances: RapidAppearanceValues,
        anchorText: 'Anchor',
    } }, StylesMapperTemplate);
export const FastAnchorAppearances = Object.assign({ args: {
        appearances: FastAppearanceValues,
        anchorText: 'Anchor',
    } }, StylesMapperTemplate);
