import { html } from 'lit-html';
const meta = {
    title: 'Button',
    component: 'rapid-button',
};
export default meta;
const wrapperStyle = 'display: flex; flex-direction: column;';
const textStyle = 'font-size:13px;font-weight:600;color:white; padding: 8px 0px;';
const StylesMapperTemplate = {
    render: ({ appearances }) => html `
    <div style="${wrapperStyle}">
      ${appearances.map((appearanceName) => html `
          <h3 style="${textStyle}">${appearanceName}</div>
          <div style="display: flex; flex-direction: row; gap:16px;margin: 8px 0;">
              <rapid-button appearance="${appearanceName}">Button</rapid-button>
              <rapid-button appearance="${appearanceName}" disabled>Button</rapid-button>
              <rapid-button appearance="${appearanceName}">
                Button
                <rapid-icon name="check" size="md" slot="end"></rapid-icon>
              </rapid-button>
              <rapid-button appearance="${appearanceName}">
                Button
                <rapid-icon name="edit" size="md" slot="start"></rapid-icon>
              </rapid-button>
          </div>
          `)}
    </div>
  `,
};
const FastAppearanceValues = ['accent', 'neutral', 'outline', 'stealth', 'lightweight'];
const RapidAppearanceValues = [
    'primary',
    'primary-outline',
    'neutral',
    'neutral-outline',
    'link',
    'danger',
];
export const Default = {
    args: {
        appearance: 'primary',
        disabled: false,
    },
    argTypes: {
        appearance: {
            control: 'select',
            options: [...RapidAppearanceValues, ...FastAppearanceValues],
        },
    },
    render: ({ appearance, disabled }) => html `
    <div style="${wrapperStyle}">
      <h3 style="${textStyle}">${appearance}</div>
      <div style="display: flex; flex-direction: row; gap:16px;margin: 8px 0;">
        <rapid-button appearance="${appearance}" ?disabled="${disabled}">Button</rapid-button>
        <rapid-button appearance="${appearance}" ?disabled="${disabled}">
          Button
          <rapid-icon name="check" size="md" slot="end"></rapid-icon>
        </rapid-button>
      </div>
    </div>`,
};
export const RapidButtonAppearances = Object.assign({ args: {
        appearances: RapidAppearanceValues,
    } }, StylesMapperTemplate);
export const FastButtonAppearances = Object.assign({ args: {
        appearances: FastAppearanceValues,
    } }, StylesMapperTemplate);
