import { foundationButtonStyles } from '@genesislcap/foundation-ui';
import { css } from '@microsoft/fast-element';
import { appearanceBehavior } from '../utils';
const rapidPrimaryStyles = css `
  :host([appearance='primary']) {
    background: color-mix(in srgb, var(--accent-fill-rest), transparent 50%);
    border: calc(var(--stroke-width) * 1px) solid var(--accent-fill-rest);
  }

  :host([appearance='primary']:hover) {
    background: var(--accent-fill-rest);
  }

  :host([appearance='primary'][disabled]),
  :host([appearance='primary'][disabled]):hover,
  :host([appearance='primary'][disabled]):active {
    background: color-mix(in srgb, var(--accent-fill-rest), transparent 70%);
    border: calc(var(--stroke-width) * 1px) solid var(--accent-fill-rest);
    color: color-mix(in srgb, var(--neutral-foreground-rest), transparent 50%);
    opacity: 100%;
  }

  :host([appearance='primary']:active) {
    background: color-mix(in srgb, var(--accent-fill-rest), transparent 70%);
    border: calc(var(--stroke-width) * 1px) solid var(--accent-fill-rest);
  }
`;
const rapidDangerStyles = css `
  :host([appearance='danger']) {
    background: color-mix(in srgb, var(--error-color), transparent 50%);
    border: calc(var(--stroke-width) * 1px) solid var(--error-color);
  }

  :host([appearance='danger']:hover) {
    background: var(--error-color);
  }

  :host([appearance='danger'][disabled]),
  :host([appearance='danger'][disabled]):hover,
  :host([appearance='danger'][disabled]):active {
    background: color-mix(in srgb, var(--error-color), transparent 70%);
    border: calc(var(--stroke-width) * 1px) solid var(--error-color);
    color: color-mix(in srgb, var(--neutral-foreground-rest), transparent 50%);
    opacity: 100%;
  }

  :host([appearance='danger']:active) {
    background: color-mix(in srgb, var(--error-color), transparent 70%);
    border: calc(var(--stroke-width) * 1px) solid var(--error-color);
  }
`;
const rapidPrimaryOutlineStyles = css `
  :host([appearance='primary-outline']) {
    background: none;
    border: calc(var(--stroke-width) * 1px) solid var(--accent-fill-rest);
  }

  :host([appearance='primary-outline']:hover) {
    background: color-mix(in srgb, var(--accent-fill-rest), transparent 50%);
  }

  :host([appearance='primary-outline'][disabled]),
  :host([appearance='primary-outline'][disabled]):hover,
  :host([appearance='primary-outline'][disabled]):active {
    background: none;
    border: calc(var(--stroke-width) * 1px) solid var(--accent-fill-rest);
    color: color-mix(in srgb, var(--neutral-foreground-rest), transparent 50%);
    opacity: 100%;
  }
`;
const rapidNeutralOutlineStyles = css `
  :host([appearance='neutral-outline']) {
    background: none;
    border: calc(var(--stroke-width) * 1px) solid var(--neutral-fill-rest);
  }

  :host([appearance='neutral-outline']:hover) {
    background: color-mix(in srgb, var(--neutral-fill-rest), transparent 50%);
  }

  :host([appearance='neutral-outline'][disabled]),
  :host([appearance='neutral-outline'][disabled]):hover,
  :host([appearance='neutral-outline'][disabled]):active {
    background: none;
    border: calc(var(--stroke-width) * 1px) solid var(--neutral-fill-rest);
    color: color-mix(in srgb, var(--neutral-foreground-rest), transparent 50%);
    opacity: 100%;
  }
`;
const rapidLinkStyles = css `
  :host([appearance='link']) {
    background: none;
    border: none;
    color: color-mix(in srgb, var(--accent-fill-rest), transparent 35%);
  }

  :host([appearance='link']) .control {
    padding: 0;
  }

  :host([appearance='link']:hover) {
    color: var(--accent-fill-rest);
    background: none;
  }

  :host([appearance='link'][disabled]),
  :host([appearance='link'][disabled]):hover,
  :host([appearance='link'][disabled]):active {
    background: none;
    color: color-mix(in srgb, var(--accent-fill-rest), transparent 35%);
    opacity: 100%;
  }
`;
const baseStyles = (context, definition) => css `
  :host {
    font-weight: 500;
    color: var(--neutral-foreground-rest);
    box-sizing: border-box;
    font-size: var(--type-ramp-minus-1-font-size);
    height: calc(((var(--base-height-multiplier) + var(--density)) * var(--design-unit) - 4) * 1px);
  }

  .control {
    padding: 0 calc((16 + var(--design-unit) * 2 * var(--density)) * 1px);
  }

  .start {
    margin-inline-end: calc(var(--design-unit) * 2px);
  }

  .end {
    margin-inline-start: calc(var(--design-unit) * 2px);
  }

  .control:has(.start) {
    padding-left: calc((12 + var(--design-unit) * 2 * var(--density)) * 1px);
  }

  .control:has(.end) {
    padding-right: calc((12 + var(--design-unit) * 2 * var(--density)) * 1px);
  }

  :host([appearance='neutral']) {
    background: color-mix(in srgb, var(--neutral-fill-rest), transparent 50%);
    border: calc(var(--stroke-width) * 1px) solid var(--neutral-fill-rest);
  }

  :host([appearance='neutral']:hover) {
    background: var(--neutral-fill-rest);
  }

  :host([appearance='neutral']:active) {
    background: color-mix(in srgb, var(--neutral-fill-rest), transparent 70%));
    border: calc(var(--stroke-width) * 1px) solid var(--neutral-fill-rest);
  }

  :host([appearance='neutral'][disabled]),
  :host([appearance='neutral'][disabled]):hover,
  :host([appearance='neutral'][disabled]):active {
    background: color-mix(in srgb, var(--neutral-fill-rest), transparent 70%);
    border: calc(var(--stroke-width) * 1px) solid var(--neutral-fill-rest);
    color: color-mix(in srgb, var(--neutral-foreground-rest), transparent 50%);
    opacity: 100%;
  }
`;
export const rapidButtonStyles = (context, definition) => css `
    ${foundationButtonStyles(context, definition)}
    ${baseStyles(context, definition)}
  `.withBehaviors(appearanceBehavior('primary', rapidPrimaryStyles), appearanceBehavior('danger', rapidDangerStyles), appearanceBehavior('primary-outline', rapidPrimaryOutlineStyles), appearanceBehavior('neutral-outline', rapidNeutralOutlineStyles), appearanceBehavior('link', rapidLinkStyles));
